[llvm-commits] CVS: llvm/include/llvm/Bytecode/Format.h

Chris Lattner lattner at cs.uiuc.edu
Sun Jan 18 15:10:24 PST 2004


Changes in directory llvm/include/llvm/Bytecode:

Format.h updated: 1.8 -> 1.9

---
Log message:

Add enum for compaction table.


---
Diffs of the changes:  (+8 -2)

Index: llvm/include/llvm/Bytecode/Format.h
diff -u llvm/include/llvm/Bytecode/Format.h:1.8 llvm/include/llvm/Bytecode/Format.h:1.9
--- llvm/include/llvm/Bytecode/Format.h:1.8	Mon Dec  1 01:08:06 2003
+++ llvm/include/llvm/Bytecode/Format.h	Sun Jan 18 15:09:23 2004
@@ -36,11 +36,17 @@
     // Function subtypes:
     // Can also have ConstantPool block
     // Can also have SymbolTable block
-    BasicBlock = 0x31,        // May contain many basic blocks
+    BasicBlock = 0x31,// May contain many basic blocks (obsolete since LLVM 1.1)
 
     // InstructionList - The instructions in the body of a function.  This
     // superceeds the old BasicBlock node.
     InstructionList = 0x32,
+
+    // CompactionTable - blocks with this id are used to define local remapping
+    // tables for a function, allowing the indices used within the function to
+    // be as small as possible.  This often allows the instructions to be
+    // encoded more efficiently.
+    CompactionTable = 0x33,
   };
 };
 
@@ -36,11 +36,17 @@
 
     // InstructionList - The instructions in the body of a function.  This
-    // superceeds the old BasicBlock node.
+    // superceeds the old BasicBlock node used in LLVM 1.0.
     InstructionList = 0x32,





More information about the llvm-commits mailing list